==> release-0.13.zip: docs/docs/knative-offerings.md <==
---
title: "Knative Offerings"
linkTitle: "Knative Offerings"
weight: 15
type: "docs"
---

Knative has a rich community with many vendors participating, and many of those
vendors offer commercial Knative products.  Please check with each of these
vendors for what is or is not supported.

<!-- TODO: Talk about criteria for inclusion here?  a la Conformance -->

Here is a list of commercial Knative products (alphabetically):

- [Gardener](https://gardener.cloud/050-tutorials/content/howto/knative-install/): Install Knative in Gardener's vanilla Kubernetes clusters to add an extra layer of serveless runtime.
- [Google Cloud Run for Anthos](https://cloud.google.com/run/docs/gke/setup): extend Google Kubernetes Engine with a flexible serverless development platform. With Cloud Run for Anthos, you get the operational flexibility of Kubernetes with the developer experience of Serverless, allowing you to deploy and manage Knative based services on your own cluster.
- [Google Cloud Run](https://cloud.google.com/run/docs/setup): A fully-managed Knative-based serverless platform. With no Kubernetes cluster to manage, Cloud Run lets you go from container to production in seconds.
- [Managed Knative for IBM Cloud Kubernetes Service](https://cloud.ibm.com/docs/containers?topic=containers-serverless-apps-knative): is a managed add-on for the [IBM Kubernetes Service](https://cloud.ibm.com/docs/containers?topic=containers-getting-started) that enables you to deploy and manage Knative based services on your own Kubernetes cluster.
- [Openshift Serverless](https://access.redhat.com/documentation/en-us/openshift_container_platform/4.3/html-single/serverless_applications/index): on OpenShift Container Platform enables stateful, stateless, and serverless workloads to all run on a single multi-cloud container platform with automated operations. Developers can use a single platform for hosting their microservices, legacy, and serverless applications.
- [Pivotal Function Service (PFS)](https://docs.pivotal.io/pfs): is a platform for building and running functions, applications, and containers on Kubernetes. PFS is based on the [riff](https://projectriff.io) open source project.
- [TriggerMesh Cloud](https://cloud.triggermesh.io): A fully-managed Knative and Tekton cloud-native integration platform. With support for AWS, Azure and Google event sources and brokers.

<!-- TODO: In which category do we put SAP/Kyma? -->

<!-- TODO(you!): Add a new section if your project builds ON Knative (vs. offering it directly)  -->

==> release-0.18.zip: docs/docs/knative-offerings.md <==
---
title: "Knative Offerings"
linkTitle: "Knative Offerings"
weight: 15
type: "docs"
---

Knative has a rich community with many vendors participating, and many of those
vendors offer commercial Knative products.  Please check with each of these
vendors for what is or is not supported.

<!-- TODO: Talk about criteria for inclusion here?  a la Conformance -->

Here is a list of commercial Knative products (alphabetically):

- [Gardener](https://gardener.cloud/documentation/050-tutorials/content/howto/knative-install/): Install Knative in Gardener's vanilla Kubernetes clusters to add an extra layer of serverless runtime.
- [Google Cloud Run for Anthos](https://cloud.google.com/run/docs/gke/setup): extend Google Kubernetes Engine with a flexible serverless development platform. With Cloud Run for Anthos, you get the operational flexibility of Kubernetes with the developer experience of Serverless, allowing you to deploy and manage Knative based services on your own cluster.
- [Google Cloud Run](https://cloud.google.com/run/docs/setup): A fully-managed Knative-based serverless platform. With no Kubernetes cluster to manage, Cloud Run lets you go from container to production in seconds.
- [Managed Knative for IBM Cloud Kubernetes Service](https://cloud.ibm.com/docs/containers?topic=containers-serverless-apps-knative): is a managed add-on for the [IBM Kubernetes Service](https://cloud.ibm.com/docs/containers?topic=containers-getting-started) that enables you to deploy and manage Knative based services on your own Kubernetes cluster.
- [Red Hat Openshift Serverless](https://docs.openshift.com/container-platform/4.6/serverless/serverless-getting-started.html): enables stateful, stateless, and serverless workloads to all run on a single multi-cloud container platform with automated operations. Developers can use a single platform for hosting their microservices, legacy, and serverless applications.
- [Pivotal Function Service (PFS)](https://docs.pivotal.io/pfs): is a platform for building and running functions, applications, and containers on Kubernetes. PFS is based on the [riff](https://projectriff.io) open source project.
- [TriggerMesh Cloud](https://cloud.triggermesh.io): A fully-managed Knative and Tekton cloud-native integration platform. With support for AWS, Azure and Google event sources and brokers.

<!-- TODO: In which category do we put SAP/Kyma? -->

<!-- TODO(you!): Add a new section if your project builds ON Knative (vs. offering it directly)  -->
